sqlite3

package
v0.2.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DefaultTablePrefix = "at_"

Functions

func MigrateDB

func MigrateDB(ctx context.Context, cfg *config.Migrate) error

Types

type SQLite

type SQLite struct {
	// contains filtered or unexported fields
}

func New

func New(ctx context.Context, cfg *config.StoreSQLite, encKey []byte) (*SQLite, error)

func (*SQLite) AccumulateUsage added in v0.2.0

func (s *SQLite) AccumulateUsage(ctx context.Context, agentID string, inputTokens, outputTokens, costCents int64) error

func (*SQLite) AddLabelToTask added in v0.2.0

func (s *SQLite) AddLabelToTask(ctx context.Context, taskID, labelID string) error

func (*SQLite) CheckoutTask added in v0.2.0

func (s *SQLite) CheckoutTask(ctx context.Context, taskID, agentID string) error

func (*SQLite) Close

func (s *SQLite) Close()

func (*SQLite) CreateAPIToken

func (s *SQLite) CreateAPIToken(ctx context.Context, token service.APIToken, tokenHash string) (*service.APIToken, error)

func (*SQLite) CreateAgent added in v0.2.0

func (s *SQLite) CreateAgent(ctx context.Context, agent service.Agent) (*service.Agent, error)

func (*SQLite) CreateAgentMemory added in v0.2.0

func (s *SQLite) CreateAgentMemory(ctx context.Context, mem service.AgentMemory) (*service.AgentMemory, error)

func (*SQLite) CreateAgentMemoryMessages added in v0.2.0

func (s *SQLite) CreateAgentMemoryMessages(ctx context.Context, msgs service.AgentMemoryMessages) error

func (*SQLite) CreateApproval added in v0.2.0

func (s *SQLite) CreateApproval(ctx context.Context, approval service.Approval) (*service.Approval, error)

func (*SQLite) CreateBotConfig added in v0.2.0

func (s *SQLite) CreateBotConfig(ctx context.Context, bot service.BotConfig) (*service.BotConfig, error)

func (*SQLite) CreateChatMessage added in v0.2.0

func (s *SQLite) CreateChatMessage(ctx context.Context, msg service.ChatMessage) (*service.ChatMessage, error)

func (*SQLite) CreateChatMessages added in v0.2.0

func (s *SQLite) CreateChatMessages(ctx context.Context, msgs []service.ChatMessage) error

func (*SQLite) CreateChatSession added in v0.2.0

func (s *SQLite) CreateChatSession(ctx context.Context, session service.ChatSession) (*service.ChatSession, error)

func (*SQLite) CreateComment added in v0.2.0

func (s *SQLite) CreateComment(ctx context.Context, comment service.IssueComment) (*service.IssueComment, error)

func (*SQLite) CreateConnection added in v0.2.1

func (s *SQLite) CreateConnection(ctx context.Context, c service.Connection) (*service.Connection, error)

func (*SQLite) CreateGoal added in v0.2.0

func (s *SQLite) CreateGoal(ctx context.Context, goal service.Goal) (*service.Goal, error)

func (*SQLite) CreateGuide added in v0.2.1

func (s *SQLite) CreateGuide(ctx context.Context, g service.Guide) (*service.Guide, error)

func (*SQLite) CreateHeartbeatRun added in v0.2.0

func (s *SQLite) CreateHeartbeatRun(ctx context.Context, run service.HeartbeatRun) (*service.HeartbeatRun, error)

func (*SQLite) CreateLabel added in v0.2.0

func (s *SQLite) CreateLabel(ctx context.Context, label service.Label) (*service.Label, error)

func (*SQLite) CreateMCPServer added in v0.2.0

func (s *SQLite) CreateMCPServer(ctx context.Context, srv service.MCPServer) (*service.MCPServer, error)

func (*SQLite) CreateMCPSet added in v0.2.0

func (s *SQLite) CreateMCPSet(ctx context.Context, set service.MCPSet) (*service.MCPSet, error)

func (*SQLite) CreateMarketplaceSource added in v0.2.0

func (s *SQLite) CreateMarketplaceSource(ctx context.Context, src service.MarketplaceSource) (*service.MarketplaceSource, error)

func (*SQLite) CreateNodeConfig added in v0.2.0

func (s *SQLite) CreateNodeConfig(ctx context.Context, nc service.NodeConfig) (*service.NodeConfig, error)

func (*SQLite) CreateOrCoalesce added in v0.2.0

func (s *SQLite) CreateOrCoalesce(ctx context.Context, req service.WakeupRequest) (*service.WakeupRequest, error)

func (*SQLite) CreateOrganization added in v0.2.0

func (s *SQLite) CreateOrganization(ctx context.Context, org service.Organization) (*service.Organization, error)

func (*SQLite) CreateOrganizationAgent added in v0.2.0

func (s *SQLite) CreateOrganizationAgent(ctx context.Context, oa service.OrganizationAgent) (*service.OrganizationAgent, error)

func (*SQLite) CreatePackSource added in v0.2.1

func (s *SQLite) CreatePackSource(ctx context.Context, ps service.PackSource) (*service.PackSource, error)

func (*SQLite) CreateProject added in v0.2.0

func (s *SQLite) CreateProject(ctx context.Context, project service.Project) (*service.Project, error)

func (*SQLite) CreateProvider

func (s *SQLite) CreateProvider(ctx context.Context, record service.ProviderRecord) (*service.ProviderRecord, error)

func (*SQLite) CreateRAGCollection added in v0.2.0

func (s *SQLite) CreateRAGCollection(ctx context.Context, c service.RAGCollection) (*service.RAGCollection, error)

func (*SQLite) CreateRevision added in v0.2.0

func (*SQLite) CreateSkill added in v0.2.0

func (s *SQLite) CreateSkill(ctx context.Context, sk service.Skill) (*service.Skill, error)

func (*SQLite) CreateTask added in v0.2.0

func (s *SQLite) CreateTask(ctx context.Context, task service.Task) (*service.Task, error)

func (*SQLite) CreateTrigger added in v0.2.0

func (s *SQLite) CreateTrigger(ctx context.Context, t service.Trigger) (*service.Trigger, error)

func (*SQLite) CreateVariable added in v0.2.0

func (s *SQLite) CreateVariable(ctx context.Context, v service.Variable) (*service.Variable, error)

func (*SQLite) CreateWorkflow added in v0.2.0

func (s *SQLite) CreateWorkflow(ctx context.Context, w service.Workflow) (*service.Workflow, error)

func (*SQLite) CreateWorkflowVersion added in v0.2.0

func (s *SQLite) CreateWorkflowVersion(ctx context.Context, v service.WorkflowVersion) (*service.WorkflowVersion, error)

func (*SQLite) DeleteAPIToken

func (s *SQLite) DeleteAPIToken(ctx context.Context, id string) error

func (*SQLite) DeleteAgent added in v0.2.0

func (s *SQLite) DeleteAgent(ctx context.Context, id string) error

func (*SQLite) DeleteAgentMemory added in v0.2.0

func (s *SQLite) DeleteAgentMemory(ctx context.Context, id string) error

func (*SQLite) DeleteAgentTaskSession added in v0.2.0

func (s *SQLite) DeleteAgentTaskSession(ctx context.Context, agentID, taskKey string) error

func (*SQLite) DeleteBotConfig added in v0.2.0

func (s *SQLite) DeleteBotConfig(ctx context.Context, id string) error

func (*SQLite) DeleteChatMessages added in v0.2.0

func (s *SQLite) DeleteChatMessages(ctx context.Context, sessionID string) error

func (*SQLite) DeleteChatSession added in v0.2.0

func (s *SQLite) DeleteChatSession(ctx context.Context, id string) error

func (*SQLite) DeleteComment added in v0.2.0

func (s *SQLite) DeleteComment(ctx context.Context, id string) error

func (*SQLite) DeleteConnection added in v0.2.1

func (s *SQLite) DeleteConnection(ctx context.Context, id string) error

func (*SQLite) DeleteGoal added in v0.2.0

func (s *SQLite) DeleteGoal(ctx context.Context, id string) error

func (*SQLite) DeleteGuide added in v0.2.1

func (s *SQLite) DeleteGuide(ctx context.Context, id string) error

func (*SQLite) DeleteLabel added in v0.2.0

func (s *SQLite) DeleteLabel(ctx context.Context, id string) error

func (*SQLite) DeleteMCPServer added in v0.2.0

func (s *SQLite) DeleteMCPServer(ctx context.Context, id string) error

func (*SQLite) DeleteMCPSet added in v0.2.0

func (s *SQLite) DeleteMCPSet(ctx context.Context, id string) error

func (*SQLite) DeleteMarketplaceSource added in v0.2.0

func (s *SQLite) DeleteMarketplaceSource(ctx context.Context, id string) error

func (*SQLite) DeleteNodeConfig added in v0.2.0

func (s *SQLite) DeleteNodeConfig(ctx context.Context, id string) error

func (*SQLite) DeleteOrganization added in v0.2.0

func (s *SQLite) DeleteOrganization(ctx context.Context, id string) error

func (*SQLite) DeleteOrganizationAgent added in v0.2.0

func (s *SQLite) DeleteOrganizationAgent(ctx context.Context, id string) error

func (*SQLite) DeleteOrganizationAgentByPair added in v0.2.0

func (s *SQLite) DeleteOrganizationAgentByPair(ctx context.Context, orgID, agentID string) error

func (*SQLite) DeletePackSource added in v0.2.1

func (s *SQLite) DeletePackSource(ctx context.Context, id string) error

func (*SQLite) DeleteProject added in v0.2.0

func (s *SQLite) DeleteProject(ctx context.Context, id string) error

func (*SQLite) DeleteProvider

func (s *SQLite) DeleteProvider(ctx context.Context, key string) error

func (*SQLite) DeleteRAGCollection added in v0.2.0

func (s *SQLite) DeleteRAGCollection(ctx context.Context, id string) error

func (*SQLite) DeleteRAGPage added in v0.2.0

func (s *SQLite) DeleteRAGPage(ctx context.Context, id string) error

func (*SQLite) DeleteRAGPageBySource added in v0.2.0

func (s *SQLite) DeleteRAGPageBySource(ctx context.Context, collectionID, source string) error

func (*SQLite) DeleteRAGPagesByCollectionID added in v0.2.0

func (s *SQLite) DeleteRAGPagesByCollectionID(ctx context.Context, collectionID string) error

func (*SQLite) DeleteSkill added in v0.2.0

func (s *SQLite) DeleteSkill(ctx context.Context, id string) error

func (*SQLite) DeleteTask added in v0.2.0

func (s *SQLite) DeleteTask(ctx context.Context, id string) error

func (*SQLite) DeleteTrigger added in v0.2.0

func (s *SQLite) DeleteTrigger(ctx context.Context, id string) error

func (*SQLite) DeleteUserPreference added in v0.2.0

func (s *SQLite) DeleteUserPreference(ctx context.Context, userID, key string) error

func (*SQLite) DeleteVariable added in v0.2.0

func (s *SQLite) DeleteVariable(ctx context.Context, id string) error

func (*SQLite) DeleteWorkflow added in v0.2.0

func (s *SQLite) DeleteWorkflow(ctx context.Context, id string) error

func (*SQLite) GetAPITokenByHash

func (s *SQLite) GetAPITokenByHash(ctx context.Context, hash string) (*service.APIToken, error)

func (*SQLite) GetActiveRun added in v0.2.0

func (s *SQLite) GetActiveRun(ctx context.Context, agentID string) (*service.HeartbeatRun, error)

func (*SQLite) GetAgent added in v0.2.0

func (s *SQLite) GetAgent(ctx context.Context, id string) (*service.Agent, error)

func (*SQLite) GetAgentBudget added in v0.2.0

func (s *SQLite) GetAgentBudget(ctx context.Context, agentID string) (*service.AgentBudget, error)

func (*SQLite) GetAgentMemory added in v0.2.0

func (s *SQLite) GetAgentMemory(ctx context.Context, id string) (*service.AgentMemory, error)

func (*SQLite) GetAgentMemoryMessages added in v0.2.0

func (s *SQLite) GetAgentMemoryMessages(ctx context.Context, memoryID string) (*service.AgentMemoryMessages, error)

func (*SQLite) GetAgentRuntimeState added in v0.2.0

func (s *SQLite) GetAgentRuntimeState(ctx context.Context, agentID string) (*service.AgentRuntimeState, error)

func (*SQLite) GetAgentTaskSession added in v0.2.0

func (s *SQLite) GetAgentTaskSession(ctx context.Context, agentID, taskKey string) (*service.AgentTaskSession, error)

func (*SQLite) GetAgentTotalSpend added in v0.2.0

func (s *SQLite) GetAgentTotalSpend(ctx context.Context, agentID string) (float64, error)

func (*SQLite) GetAgentUsage added in v0.2.0

func (s *SQLite) GetAgentUsage(ctx context.Context, agentID string, q *query.Query) (*service.ListResult[service.AgentUsageRecord], error)

func (*SQLite) GetApproval added in v0.2.0

func (s *SQLite) GetApproval(ctx context.Context, id string) (*service.Approval, error)

func (*SQLite) GetAuditTrail added in v0.2.0

func (s *SQLite) GetAuditTrail(ctx context.Context, resourceType, resourceID string) ([]service.AuditEntry, error)

func (*SQLite) GetBotConfig added in v0.2.0

func (s *SQLite) GetBotConfig(ctx context.Context, id string) (*service.BotConfig, error)

func (*SQLite) GetChatSession added in v0.2.0

func (s *SQLite) GetChatSession(ctx context.Context, id string) (*service.ChatSession, error)

func (*SQLite) GetChatSessionByPlatform added in v0.2.0

func (s *SQLite) GetChatSessionByPlatform(ctx context.Context, platform, platformUserID, platformChannelID string) (*service.ChatSession, error)

func (*SQLite) GetChatSessionByTaskID added in v0.2.0

func (s *SQLite) GetChatSessionByTaskID(ctx context.Context, taskID string) (*service.ChatSession, error)

func (*SQLite) GetComment added in v0.2.0

func (s *SQLite) GetComment(ctx context.Context, id string) (*service.IssueComment, error)

func (*SQLite) GetConnection added in v0.2.1

func (s *SQLite) GetConnection(ctx context.Context, id string) (*service.Connection, error)

func (*SQLite) GetConnectionByName added in v0.2.1

func (s *SQLite) GetConnectionByName(ctx context.Context, provider, name string) (*service.Connection, error)

func (*SQLite) GetCostByAgent added in v0.2.0

func (s *SQLite) GetCostByAgent(ctx context.Context, agentID string) (float64, error)

func (*SQLite) GetCostByBillingCode added in v0.2.0

func (s *SQLite) GetCostByBillingCode(ctx context.Context, billingCode string) (float64, error)

func (*SQLite) GetCostByGoal added in v0.2.0

func (s *SQLite) GetCostByGoal(ctx context.Context, goalID string) (float64, error)

func (*SQLite) GetCostByProject added in v0.2.0

func (s *SQLite) GetCostByProject(ctx context.Context, projectID string) (float64, error)

func (*SQLite) GetGoal added in v0.2.0

func (s *SQLite) GetGoal(ctx context.Context, id string) (*service.Goal, error)

func (*SQLite) GetGoalAncestry added in v0.2.0

func (s *SQLite) GetGoalAncestry(ctx context.Context, id string) ([]service.Goal, error)

func (*SQLite) GetGuide added in v0.2.1

func (s *SQLite) GetGuide(ctx context.Context, id string) (*service.Guide, error)

func (*SQLite) GetHeartbeat added in v0.2.0

func (s *SQLite) GetHeartbeat(ctx context.Context, agentID string) (*service.AgentHeartbeat, error)

func (*SQLite) GetHeartbeatRun added in v0.2.0

func (s *SQLite) GetHeartbeatRun(ctx context.Context, id string) (*service.HeartbeatRun, error)

func (*SQLite) GetLabel added in v0.2.0

func (s *SQLite) GetLabel(ctx context.Context, id string) (*service.Label, error)

func (*SQLite) GetLatestRevision added in v0.2.0

func (s *SQLite) GetLatestRevision(ctx context.Context, agentID string) (*service.AgentConfigRevision, error)

func (*SQLite) GetMCPServer added in v0.2.0

func (s *SQLite) GetMCPServer(ctx context.Context, id string) (*service.MCPServer, error)

func (*SQLite) GetMCPServerByName added in v0.2.0

func (s *SQLite) GetMCPServerByName(ctx context.Context, name string) (*service.MCPServer, error)

func (*SQLite) GetMCPSet added in v0.2.0

func (s *SQLite) GetMCPSet(ctx context.Context, id string) (*service.MCPSet, error)

func (*SQLite) GetMCPSetByName added in v0.2.0

func (s *SQLite) GetMCPSetByName(ctx context.Context, name string) (*service.MCPSet, error)

func (*SQLite) GetMarketplaceSource added in v0.2.0

func (s *SQLite) GetMarketplaceSource(ctx context.Context, id string) (*service.MarketplaceSource, error)

func (*SQLite) GetNodeConfig added in v0.2.0

func (s *SQLite) GetNodeConfig(ctx context.Context, id string) (*service.NodeConfig, error)

func (*SQLite) GetOrganization added in v0.2.0

func (s *SQLite) GetOrganization(ctx context.Context, id string) (*service.Organization, error)

func (*SQLite) GetOrganizationAgent added in v0.2.0

func (s *SQLite) GetOrganizationAgent(ctx context.Context, id string) (*service.OrganizationAgent, error)

func (*SQLite) GetOrganizationAgentByPair added in v0.2.0

func (s *SQLite) GetOrganizationAgentByPair(ctx context.Context, orgID, agentID string) (*service.OrganizationAgent, error)

func (*SQLite) GetPackSource added in v0.2.1

func (s *SQLite) GetPackSource(ctx context.Context, id string) (*service.PackSource, error)

func (*SQLite) GetProject added in v0.2.0

func (s *SQLite) GetProject(ctx context.Context, id string) (*service.Project, error)

func (*SQLite) GetProvider

func (s *SQLite) GetProvider(ctx context.Context, key string) (*service.ProviderRecord, error)

func (*SQLite) GetRAGCollection added in v0.2.0

func (s *SQLite) GetRAGCollection(ctx context.Context, id string) (*service.RAGCollection, error)

func (*SQLite) GetRAGCollectionByName added in v0.2.0

func (s *SQLite) GetRAGCollectionByName(ctx context.Context, name string) (*service.RAGCollection, error)

func (*SQLite) GetRAGPage added in v0.2.0

func (s *SQLite) GetRAGPage(ctx context.Context, id string) (*service.RAGPage, error)

func (*SQLite) GetRAGPageBySource added in v0.2.0

func (s *SQLite) GetRAGPageBySource(ctx context.Context, collectionID, source string) (*service.RAGPage, error)

func (*SQLite) GetRAGState added in v0.2.0

func (s *SQLite) GetRAGState(ctx context.Context, key string) (*service.RAGState, error)

func (*SQLite) GetRevision added in v0.2.0

func (s *SQLite) GetRevision(ctx context.Context, id string) (*service.AgentConfigRevision, error)

func (*SQLite) GetSkill added in v0.2.0

func (s *SQLite) GetSkill(ctx context.Context, id string) (*service.Skill, error)

func (*SQLite) GetSkillByName added in v0.2.0

func (s *SQLite) GetSkillByName(ctx context.Context, name string) (*service.Skill, error)

func (*SQLite) GetTask added in v0.2.0

func (s *SQLite) GetTask(ctx context.Context, id string) (*service.Task, error)

func (*SQLite) GetTokenTotalUsage added in v0.2.0

func (s *SQLite) GetTokenTotalUsage(ctx context.Context, tokenID string) (int64, error)

func (*SQLite) GetTokenUsage added in v0.2.0

func (s *SQLite) GetTokenUsage(ctx context.Context, tokenID string) ([]service.TokenUsage, error)

func (*SQLite) GetTrigger added in v0.2.0

func (s *SQLite) GetTrigger(ctx context.Context, id string) (*service.Trigger, error)

func (*SQLite) GetTriggerByAlias added in v0.2.0

func (s *SQLite) GetTriggerByAlias(ctx context.Context, alias string) (*service.Trigger, error)

func (*SQLite) GetUsageGrouped added in v0.2.1

func (s *SQLite) GetUsageGrouped(ctx context.Context, filter service.UsageFilter, groupBy string, limit int) ([]service.UsageSummary, error)

func (*SQLite) GetUsageSummary added in v0.2.1

func (s *SQLite) GetUsageSummary(ctx context.Context, filter service.UsageFilter) (service.UsageSummary, error)

func (*SQLite) GetUsageTimeSeries added in v0.2.1

func (s *SQLite) GetUsageTimeSeries(ctx context.Context, filter service.UsageFilter, bucket string) ([]service.UsageTimeSeriesPoint, error)

func (*SQLite) GetUserPreference added in v0.2.0

func (s *SQLite) GetUserPreference(ctx context.Context, userID, key string) (*service.UserPreference, error)

func (*SQLite) GetVariable added in v0.2.0

func (s *SQLite) GetVariable(ctx context.Context, id string) (*service.Variable, error)

func (*SQLite) GetVariableByKey added in v0.2.0

func (s *SQLite) GetVariableByKey(ctx context.Context, key string) (*service.Variable, error)

func (*SQLite) GetWakeupRequest added in v0.2.0

func (s *SQLite) GetWakeupRequest(ctx context.Context, id string) (*service.WakeupRequest, error)

func (*SQLite) GetWorkflow added in v0.2.0

func (s *SQLite) GetWorkflow(ctx context.Context, id string) (*service.Workflow, error)

func (*SQLite) GetWorkflowByName added in v0.2.1

func (s *SQLite) GetWorkflowByName(ctx context.Context, name string) (*service.Workflow, error)

func (*SQLite) GetWorkflowVersion added in v0.2.0

func (s *SQLite) GetWorkflowVersion(ctx context.Context, workflowID string, version int) (*service.WorkflowVersion, error)

func (*SQLite) IncrementIssueCounter added in v0.2.0

func (s *SQLite) IncrementIssueCounter(ctx context.Context, orgID string) (int64, error)

func (*SQLite) ListAPITokens

func (s *SQLite) ListAPITokens(ctx context.Context, q *query.Query) (*service.ListResult[service.APIToken], error)

func (*SQLite) ListAgentBudgets added in v0.2.1

func (s *SQLite) ListAgentBudgets(ctx context.Context) ([]service.AgentBudget, error)

ListAgentBudgets returns every configured agent budget.

func (*SQLite) ListAgentMemories added in v0.2.0

func (s *SQLite) ListAgentMemories(ctx context.Context, agentID, orgID string) ([]service.AgentMemory, error)

func (*SQLite) ListAgentOrganizations added in v0.2.0

func (s *SQLite) ListAgentOrganizations(ctx context.Context, agentID string) ([]service.OrganizationAgent, error)

func (*SQLite) ListAgentTaskSessions added in v0.2.0

func (s *SQLite) ListAgentTaskSessions(ctx context.Context, agentID string) ([]service.AgentTaskSession, error)

func (*SQLite) ListAgents added in v0.2.0

func (s *SQLite) ListAgents(ctx context.Context, q *query.Query) (*service.ListResult[service.Agent], error)

func (*SQLite) ListAllTriggers added in v0.2.0

func (s *SQLite) ListAllTriggers(ctx context.Context) ([]service.Trigger, error)

func (*SQLite) ListApprovals added in v0.2.0

func (s *SQLite) ListApprovals(ctx context.Context, q *query.Query) (*service.ListResult[service.Approval], error)

func (*SQLite) ListAuditEntries added in v0.2.0

func (s *SQLite) ListAuditEntries(ctx context.Context, q *query.Query) (*service.ListResult[service.AuditEntry], error)

func (*SQLite) ListBotConfigs added in v0.2.0

func (s *SQLite) ListBotConfigs(ctx context.Context, q *query.Query) (*service.ListResult[service.BotConfig], error)

func (*SQLite) ListChatMessages added in v0.2.0

func (s *SQLite) ListChatMessages(ctx context.Context, sessionID string) ([]service.ChatMessage, error)

func (*SQLite) ListChatSessions added in v0.2.0

func (s *SQLite) ListChatSessions(ctx context.Context, q *query.Query) (*service.ListResult[service.ChatSession], error)

func (*SQLite) ListChildTasks added in v0.2.0

func (s *SQLite) ListChildTasks(ctx context.Context, parentID string) ([]service.Task, error)

func (*SQLite) ListCommentsByTask added in v0.2.0

func (s *SQLite) ListCommentsByTask(ctx context.Context, taskID string) ([]service.IssueComment, error)

func (*SQLite) ListConnections added in v0.2.1

func (s *SQLite) ListConnections(ctx context.Context, q *query.Query) (*service.ListResult[service.Connection], error)

func (*SQLite) ListConnectionsByProvider added in v0.2.1

func (s *SQLite) ListConnectionsByProvider(ctx context.Context, provider string) ([]service.Connection, error)

func (*SQLite) ListCostEvents added in v0.2.0

func (s *SQLite) ListCostEvents(ctx context.Context, q *query.Query) (*service.ListResult[service.CostEvent], error)

func (*SQLite) ListEnabledCronTriggers added in v0.2.0

func (s *SQLite) ListEnabledCronTriggers(ctx context.Context) ([]service.Trigger, error)

func (*SQLite) ListGoals added in v0.2.0

func (s *SQLite) ListGoals(ctx context.Context, q *query.Query) (*service.ListResult[service.Goal], error)

func (*SQLite) ListGoalsByParent added in v0.2.0

func (s *SQLite) ListGoalsByParent(ctx context.Context, parentID string) ([]service.Goal, error)

func (*SQLite) ListGuides added in v0.2.1

func (s *SQLite) ListGuides(ctx context.Context, q *query.Query) (*service.ListResult[service.Guide], error)

func (*SQLite) ListHeartbeatRuns added in v0.2.0

func (s *SQLite) ListHeartbeatRuns(ctx context.Context, agentID string, q *query.Query) (*service.ListResult[service.HeartbeatRun], error)

func (*SQLite) ListHeartbeats added in v0.2.0

func (s *SQLite) ListHeartbeats(ctx context.Context) ([]service.AgentHeartbeat, error)

func (*SQLite) ListLabels added in v0.2.0

func (s *SQLite) ListLabels(ctx context.Context, orgID string) ([]service.Label, error)

func (*SQLite) ListLabelsForTask added in v0.2.0

func (s *SQLite) ListLabelsForTask(ctx context.Context, taskID string) ([]service.Label, error)

func (*SQLite) ListMCPServers added in v0.2.0

func (s *SQLite) ListMCPServers(ctx context.Context, q *query.Query) (*service.ListResult[service.MCPServer], error)

func (*SQLite) ListMCPSets added in v0.2.0

func (s *SQLite) ListMCPSets(ctx context.Context, q *query.Query) (*service.ListResult[service.MCPSet], error)

func (*SQLite) ListMarketplaceSources added in v0.2.0

func (s *SQLite) ListMarketplaceSources(ctx context.Context) ([]service.MarketplaceSource, error)

func (*SQLite) ListModelPricing added in v0.2.0

func (s *SQLite) ListModelPricing(ctx context.Context) ([]service.ModelPricing, error)

func (*SQLite) ListNodeConfigs added in v0.2.0

func (s *SQLite) ListNodeConfigs(ctx context.Context, q *query.Query) (*service.ListResult[service.NodeConfig], error)

func (*SQLite) ListNodeConfigsByType added in v0.2.0

func (s *SQLite) ListNodeConfigsByType(ctx context.Context, configType string) ([]service.NodeConfig, error)

func (*SQLite) ListOrgMemories added in v0.2.0

func (s *SQLite) ListOrgMemories(ctx context.Context, orgID string) ([]service.AgentMemory, error)

func (*SQLite) ListOrganizationAgents added in v0.2.0

func (s *SQLite) ListOrganizationAgents(ctx context.Context, orgID string) ([]service.OrganizationAgent, error)

func (*SQLite) ListOrganizations added in v0.2.0

func (s *SQLite) ListOrganizations(ctx context.Context, q *query.Query) (*service.ListResult[service.Organization], error)

func (*SQLite) ListPackSources added in v0.2.1

func (s *SQLite) ListPackSources(ctx context.Context, q *query.Query) (*service.ListResult[service.PackSource], error)

func (*SQLite) ListPendingApprovals added in v0.2.0

func (s *SQLite) ListPendingApprovals(ctx context.Context, orgID string) ([]service.Approval, error)

func (*SQLite) ListPendingForAgent added in v0.2.0

func (s *SQLite) ListPendingForAgent(ctx context.Context, agentID string) ([]service.WakeupRequest, error)

func (*SQLite) ListProjects added in v0.2.0

func (s *SQLite) ListProjects(ctx context.Context, q *query.Query) (*service.ListResult[service.Project], error)

func (*SQLite) ListProjectsByGoal added in v0.2.0

func (s *SQLite) ListProjectsByGoal(ctx context.Context, goalID string) ([]service.Project, error)

func (*SQLite) ListProjectsByOrganization added in v0.2.0

func (s *SQLite) ListProjectsByOrganization(ctx context.Context, orgID string) ([]service.Project, error)

func (*SQLite) ListProviders

func (s *SQLite) ListProviders(ctx context.Context, q *query.Query) (*service.ListResult[service.ProviderRecord], error)

func (*SQLite) ListRAGCollections added in v0.2.0

func (s *SQLite) ListRAGCollections(ctx context.Context, q *query.Query) (*service.ListResult[service.RAGCollection], error)

func (*SQLite) ListRAGPages added in v0.2.0

func (s *SQLite) ListRAGPages(ctx context.Context, collectionID string, q *query.Query) (*service.ListResult[service.RAGPage], error)

func (*SQLite) ListRevisions added in v0.2.0

func (s *SQLite) ListRevisions(ctx context.Context, agentID string) ([]service.AgentConfigRevision, error)

func (*SQLite) ListSkills added in v0.2.0

func (s *SQLite) ListSkills(ctx context.Context, q *query.Query) (*service.ListResult[service.Skill], error)

func (*SQLite) ListTasks added in v0.2.0

func (s *SQLite) ListTasks(ctx context.Context, q *query.Query) (*service.ListResult[service.Task], error)

func (*SQLite) ListTasksByAgent added in v0.2.0

func (s *SQLite) ListTasksByAgent(ctx context.Context, agentID string) ([]service.Task, error)

func (*SQLite) ListTasksByGoal added in v0.2.0

func (s *SQLite) ListTasksByGoal(ctx context.Context, goalID string) ([]service.Task, error)

func (*SQLite) ListTasksForLabel added in v0.2.0

func (s *SQLite) ListTasksForLabel(ctx context.Context, labelID string) ([]string, error)

func (*SQLite) ListTriggers added in v0.2.0

func (s *SQLite) ListTriggers(ctx context.Context, workflowID string) ([]service.Trigger, error)

func (*SQLite) ListUserPreferences added in v0.2.0

func (s *SQLite) ListUserPreferences(ctx context.Context, userID string) ([]service.UserPreference, error)

func (*SQLite) ListVariables added in v0.2.0

func (s *SQLite) ListVariables(ctx context.Context, q *query.Query) (*service.ListResult[service.Variable], error)

func (*SQLite) ListWorkflowVersions added in v0.2.0

func (s *SQLite) ListWorkflowVersions(ctx context.Context, workflowID string) ([]service.WorkflowVersion, error)

func (*SQLite) ListWorkflows added in v0.2.0

func (s *SQLite) ListWorkflows(ctx context.Context, q *query.Query) (*service.ListResult[service.Workflow], error)

func (*SQLite) MarkDispatched added in v0.2.0

func (s *SQLite) MarkDispatched(ctx context.Context, id, runID string) error

func (*SQLite) MarkStale added in v0.2.0

func (s *SQLite) MarkStale(ctx context.Context, threshold time.Duration) (int, error)

func (*SQLite) PromoteDeferred added in v0.2.0

func (s *SQLite) PromoteDeferred(ctx context.Context, agentID string) error

func (*SQLite) RecordAgentUsage added in v0.2.0

func (s *SQLite) RecordAgentUsage(ctx context.Context, usage service.AgentUsageRecord) error

func (*SQLite) RecordAudit added in v0.2.0

func (s *SQLite) RecordAudit(ctx context.Context, entry service.AuditEntry) error

func (*SQLite) RecordCostEvent added in v0.2.0

func (s *SQLite) RecordCostEvent(ctx context.Context, event service.CostEvent) error

func (*SQLite) RecordHeartbeat added in v0.2.0

func (s *SQLite) RecordHeartbeat(ctx context.Context, agentID string, metadata map[string]any) error

func (*SQLite) RecordUsage added in v0.2.0

func (s *SQLite) RecordUsage(ctx context.Context, tokenID, model string, usage service.Usage) error

func (*SQLite) ReleaseTask added in v0.2.0

func (s *SQLite) ReleaseTask(ctx context.Context, taskID string) error

func (*SQLite) RemoveLabelFromTask added in v0.2.0

func (s *SQLite) RemoveLabelFromTask(ctx context.Context, taskID, labelID string) error

func (*SQLite) ResetTokenUsage added in v0.2.0

func (s *SQLite) ResetTokenUsage(ctx context.Context, tokenID string) error

func (*SQLite) RotateEncryptionKey added in v0.1.3

func (s *SQLite) RotateEncryptionKey(ctx context.Context, newKey []byte) error

RotateEncryptionKey decrypts all provider configs with the current key, re-encrypts them with newKey, and updates the rows atomically. Passing nil as newKey disables encryption (stores plaintext).

func (*SQLite) SearchAgentMemories added in v0.2.0

func (s *SQLite) SearchAgentMemories(ctx context.Context, agentID, orgID, query string) ([]service.AgentMemory, error)

func (*SQLite) SetActiveVersion added in v0.2.0

func (s *SQLite) SetActiveVersion(ctx context.Context, workflowID string, version int) error

func (*SQLite) SetAgentBudget added in v0.2.0

func (s *SQLite) SetAgentBudget(ctx context.Context, budget service.AgentBudget) error

func (*SQLite) SetEncryptionKey added in v0.1.3

func (s *SQLite) SetEncryptionKey(newKey []byte)

SetEncryptionKey updates the in-memory encryption key without re-encrypting database rows. Used by peer instances when they receive a key rotation broadcast from the instance that performed the actual rotation.

func (*SQLite) SetModelPricing added in v0.2.0

func (s *SQLite) SetModelPricing(ctx context.Context, pricing service.ModelPricing) error

func (*SQLite) SetRAGState added in v0.2.0

func (s *SQLite) SetRAGState(ctx context.Context, key string, value string) error

func (*SQLite) SetUserPreference added in v0.2.0

func (s *SQLite) SetUserPreference(ctx context.Context, pref service.UserPreference) error

func (*SQLite) UpdateAPIToken

func (s *SQLite) UpdateAPIToken(ctx context.Context, id string, token service.APIToken) (*service.APIToken, error)

func (*SQLite) UpdateAgent added in v0.2.0

func (s *SQLite) UpdateAgent(ctx context.Context, id string, agent service.Agent) (*service.Agent, error)

func (*SQLite) UpdateApproval added in v0.2.0

func (s *SQLite) UpdateApproval(ctx context.Context, id string, approval service.Approval) (*service.Approval, error)

func (*SQLite) UpdateBotConfig added in v0.2.0

func (s *SQLite) UpdateBotConfig(ctx context.Context, id string, bot service.BotConfig) (*service.BotConfig, error)

func (*SQLite) UpdateChatSession added in v0.2.0

func (s *SQLite) UpdateChatSession(ctx context.Context, id string, session service.ChatSession) (*service.ChatSession, error)

func (*SQLite) UpdateComment added in v0.2.0

func (s *SQLite) UpdateComment(ctx context.Context, id string, comment service.IssueComment) (*service.IssueComment, error)

func (*SQLite) UpdateConnection added in v0.2.1

func (s *SQLite) UpdateConnection(ctx context.Context, id string, c service.Connection) (*service.Connection, error)

func (*SQLite) UpdateGoal added in v0.2.0

func (s *SQLite) UpdateGoal(ctx context.Context, id string, goal service.Goal) (*service.Goal, error)

func (*SQLite) UpdateGuide added in v0.2.1

func (s *SQLite) UpdateGuide(ctx context.Context, id string, g service.Guide) (*service.Guide, error)

func (*SQLite) UpdateHeartbeatRun added in v0.2.0

func (s *SQLite) UpdateHeartbeatRun(ctx context.Context, id string, run service.HeartbeatRun) (*service.HeartbeatRun, error)

func (*SQLite) UpdateLabel added in v0.2.0

func (s *SQLite) UpdateLabel(ctx context.Context, id string, label service.Label) (*service.Label, error)

func (*SQLite) UpdateLastUsed

func (s *SQLite) UpdateLastUsed(ctx context.Context, id string) error

func (*SQLite) UpdateMCPServer added in v0.2.0

func (s *SQLite) UpdateMCPServer(ctx context.Context, id string, srv service.MCPServer) (*service.MCPServer, error)

func (*SQLite) UpdateMCPSet added in v0.2.0

func (s *SQLite) UpdateMCPSet(ctx context.Context, id string, set service.MCPSet) (*service.MCPSet, error)

func (*SQLite) UpdateMarketplaceSource added in v0.2.0

func (s *SQLite) UpdateMarketplaceSource(ctx context.Context, id string, src service.MarketplaceSource) (*service.MarketplaceSource, error)

func (*SQLite) UpdateNodeConfig added in v0.2.0

func (s *SQLite) UpdateNodeConfig(ctx context.Context, id string, nc service.NodeConfig) (*service.NodeConfig, error)

func (*SQLite) UpdateOrganization added in v0.2.0

func (s *SQLite) UpdateOrganization(ctx context.Context, id string, org service.Organization) (*service.Organization, error)

func (*SQLite) UpdateOrganizationAgent added in v0.2.0

func (s *SQLite) UpdateOrganizationAgent(ctx context.Context, id string, oa service.OrganizationAgent) (*service.OrganizationAgent, error)

func (*SQLite) UpdatePackSource added in v0.2.1

func (s *SQLite) UpdatePackSource(ctx context.Context, id string, ps service.PackSource) (*service.PackSource, error)

func (*SQLite) UpdateProject added in v0.2.0

func (s *SQLite) UpdateProject(ctx context.Context, id string, project service.Project) (*service.Project, error)

func (*SQLite) UpdateProvider

func (s *SQLite) UpdateProvider(ctx context.Context, key string, record service.ProviderRecord) (*service.ProviderRecord, error)

func (*SQLite) UpdateRAGCollection added in v0.2.0

func (s *SQLite) UpdateRAGCollection(ctx context.Context, id string, c service.RAGCollection) (*service.RAGCollection, error)

func (*SQLite) UpdateSkill added in v0.2.0

func (s *SQLite) UpdateSkill(ctx context.Context, id string, sk service.Skill) (*service.Skill, error)

func (*SQLite) UpdateTask added in v0.2.0

func (s *SQLite) UpdateTask(ctx context.Context, id string, task service.Task) (*service.Task, error)

func (*SQLite) UpdateTaskStatus added in v0.2.0

func (s *SQLite) UpdateTaskStatus(ctx context.Context, id string, status string, result string) error

func (*SQLite) UpdateTrigger added in v0.2.0

func (s *SQLite) UpdateTrigger(ctx context.Context, id string, t service.Trigger) (*service.Trigger, error)

func (*SQLite) UpdateVariable added in v0.2.0

func (s *SQLite) UpdateVariable(ctx context.Context, id string, v service.Variable) (*service.Variable, error)

func (*SQLite) UpdateWorkflow added in v0.2.0

func (s *SQLite) UpdateWorkflow(ctx context.Context, id string, w service.Workflow) (*service.Workflow, error)

func (*SQLite) UpsertAgentRuntimeState added in v0.2.0

func (s *SQLite) UpsertAgentRuntimeState(ctx context.Context, state service.AgentRuntimeState) error

func (*SQLite) UpsertAgentTaskSession added in v0.2.0

func (s *SQLite) UpsertAgentTaskSession(ctx context.Context, session service.AgentTaskSession) error

func (*SQLite) UpsertRAGPage added in v0.2.0

func (s *SQLite) UpsertRAGPage(ctx context.Context, page service.RAGPage) (*service.RAGPage, error)

Jump to