Documentation
¶
Index ¶
- Variables
- func MigrateDB(ctx context.Context, cfg *config.Migrate) error
- type SQLite
- func (s *SQLite) AccumulateUsage(ctx context.Context, agentID string, ...) error
- func (s *SQLite) AddLabelToTask(ctx context.Context, taskID, labelID string) error
- func (s *SQLite) CheckoutTask(ctx context.Context, taskID, agentID string) error
- func (s *SQLite) Close()
- func (s *SQLite) CreateAPIToken(ctx context.Context, token service.APIToken, tokenHash string) (*service.APIToken, error)
- func (s *SQLite) CreateAgent(ctx context.Context, agent service.Agent) (*service.Agent, error)
- func (s *SQLite) CreateAgentMemory(ctx context.Context, mem service.AgentMemory) (*service.AgentMemory, error)
- func (s *SQLite) CreateAgentMemoryMessages(ctx context.Context, msgs service.AgentMemoryMessages) error
- func (s *SQLite) CreateApproval(ctx context.Context, approval service.Approval) (*service.Approval, error)
- func (s *SQLite) CreateBotConfig(ctx context.Context, bot service.BotConfig) (*service.BotConfig, error)
- func (s *SQLite) CreateChatMessage(ctx context.Context, msg service.ChatMessage) (*service.ChatMessage, error)
- func (s *SQLite) CreateChatMessages(ctx context.Context, msgs []service.ChatMessage) error
- func (s *SQLite) CreateChatSession(ctx context.Context, session service.ChatSession) (*service.ChatSession, error)
- func (s *SQLite) CreateComment(ctx context.Context, comment service.IssueComment) (*service.IssueComment, error)
- func (s *SQLite) CreateConnection(ctx context.Context, c service.Connection) (*service.Connection, error)
- func (s *SQLite) CreateGoal(ctx context.Context, goal service.Goal) (*service.Goal, error)
- func (s *SQLite) CreateGuide(ctx context.Context, g service.Guide) (*service.Guide, error)
- func (s *SQLite) CreateHeartbeatRun(ctx context.Context, run service.HeartbeatRun) (*service.HeartbeatRun, error)
- func (s *SQLite) CreateLabel(ctx context.Context, label service.Label) (*service.Label, error)
- func (s *SQLite) CreateMCPServer(ctx context.Context, srv service.MCPServer) (*service.MCPServer, error)
- func (s *SQLite) CreateMCPSet(ctx context.Context, set service.MCPSet) (*service.MCPSet, error)
- func (s *SQLite) CreateMarketplaceSource(ctx context.Context, src service.MarketplaceSource) (*service.MarketplaceSource, error)
- func (s *SQLite) CreateNodeConfig(ctx context.Context, nc service.NodeConfig) (*service.NodeConfig, error)
- func (s *SQLite) CreateOrCoalesce(ctx context.Context, req service.WakeupRequest) (*service.WakeupRequest, error)
- func (s *SQLite) CreateOrganization(ctx context.Context, org service.Organization) (*service.Organization, error)
- func (s *SQLite) CreateOrganizationAgent(ctx context.Context, oa service.OrganizationAgent) (*service.OrganizationAgent, error)
- func (s *SQLite) CreatePackSource(ctx context.Context, ps service.PackSource) (*service.PackSource, error)
- func (s *SQLite) CreateProject(ctx context.Context, project service.Project) (*service.Project, error)
- func (s *SQLite) CreateProvider(ctx context.Context, record service.ProviderRecord) (*service.ProviderRecord, error)
- func (s *SQLite) CreateRAGCollection(ctx context.Context, c service.RAGCollection) (*service.RAGCollection, error)
- func (s *SQLite) CreateRevision(ctx context.Context, rev service.AgentConfigRevision) (*service.AgentConfigRevision, error)
- func (s *SQLite) CreateSkill(ctx context.Context, sk service.Skill) (*service.Skill, error)
- func (s *SQLite) CreateTask(ctx context.Context, task service.Task) (*service.Task, error)
- func (s *SQLite) CreateTrigger(ctx context.Context, t service.Trigger) (*service.Trigger, error)
- func (s *SQLite) CreateVariable(ctx context.Context, v service.Variable) (*service.Variable, error)
- func (s *SQLite) CreateWorkflow(ctx context.Context, w service.Workflow) (*service.Workflow, error)
- func (s *SQLite) CreateWorkflowVersion(ctx context.Context, v service.WorkflowVersion) (*service.WorkflowVersion, error)
- func (s *SQLite) DeleteAPIToken(ctx context.Context, id string) error
- func (s *SQLite) DeleteAgent(ctx context.Context, id string) error
- func (s *SQLite) DeleteAgentMemory(ctx context.Context, id string) error
- func (s *SQLite) DeleteAgentTaskSession(ctx context.Context, agentID, taskKey string) error
- func (s *SQLite) DeleteBotConfig(ctx context.Context, id string) error
- func (s *SQLite) DeleteChatMessages(ctx context.Context, sessionID string) error
- func (s *SQLite) DeleteChatSession(ctx context.Context, id string) error
- func (s *SQLite) DeleteComment(ctx context.Context, id string) error
- func (s *SQLite) DeleteConnection(ctx context.Context, id string) error
- func (s *SQLite) DeleteGoal(ctx context.Context, id string) error
- func (s *SQLite) DeleteGuide(ctx context.Context, id string) error
- func (s *SQLite) DeleteLabel(ctx context.Context, id string) error
- func (s *SQLite) DeleteMCPServer(ctx context.Context, id string) error
- func (s *SQLite) DeleteMCPSet(ctx context.Context, id string) error
- func (s *SQLite) DeleteMarketplaceSource(ctx context.Context, id string) error
- func (s *SQLite) DeleteNodeConfig(ctx context.Context, id string) error
- func (s *SQLite) DeleteOrganization(ctx context.Context, id string) error
- func (s *SQLite) DeleteOrganizationAgent(ctx context.Context, id string) error
- func (s *SQLite) DeleteOrganizationAgentByPair(ctx context.Context, orgID, agentID string) error
- func (s *SQLite) DeletePackSource(ctx context.Context, id string) error
- func (s *SQLite) DeleteProject(ctx context.Context, id string) error
- func (s *SQLite) DeleteProvider(ctx context.Context, key string) error
- func (s *SQLite) DeleteRAGCollection(ctx context.Context, id string) error
- func (s *SQLite) DeleteRAGPage(ctx context.Context, id string) error
- func (s *SQLite) DeleteRAGPageBySource(ctx context.Context, collectionID, source string) error
- func (s *SQLite) DeleteRAGPagesByCollectionID(ctx context.Context, collectionID string) error
- func (s *SQLite) DeleteSkill(ctx context.Context, id string) error
- func (s *SQLite) DeleteTask(ctx context.Context, id string) error
- func (s *SQLite) DeleteTrigger(ctx context.Context, id string) error
- func (s *SQLite) DeleteUserPreference(ctx context.Context, userID, key string) error
- func (s *SQLite) DeleteVariable(ctx context.Context, id string) error
- func (s *SQLite) DeleteWorkflow(ctx context.Context, id string) error
- func (s *SQLite) GetAPITokenByHash(ctx context.Context, hash string) (*service.APIToken, error)
- func (s *SQLite) GetActiveRun(ctx context.Context, agentID string) (*service.HeartbeatRun, error)
- func (s *SQLite) GetAgent(ctx context.Context, id string) (*service.Agent, error)
- func (s *SQLite) GetAgentBudget(ctx context.Context, agentID string) (*service.AgentBudget, error)
- func (s *SQLite) GetAgentMemory(ctx context.Context, id string) (*service.AgentMemory, error)
- func (s *SQLite) GetAgentMemoryMessages(ctx context.Context, memoryID string) (*service.AgentMemoryMessages, error)
- func (s *SQLite) GetAgentRuntimeState(ctx context.Context, agentID string) (*service.AgentRuntimeState, error)
- func (s *SQLite) GetAgentTaskSession(ctx context.Context, agentID, taskKey string) (*service.AgentTaskSession, error)
- func (s *SQLite) GetAgentTotalSpend(ctx context.Context, agentID string) (float64, error)
- func (s *SQLite) GetAgentUsage(ctx context.Context, agentID string, q *query.Query) (*service.ListResult[service.AgentUsageRecord], error)
- func (s *SQLite) GetApproval(ctx context.Context, id string) (*service.Approval, error)
- func (s *SQLite) GetAuditTrail(ctx context.Context, resourceType, resourceID string) ([]service.AuditEntry, error)
- func (s *SQLite) GetBotConfig(ctx context.Context, id string) (*service.BotConfig, error)
- func (s *SQLite) GetChatSession(ctx context.Context, id string) (*service.ChatSession, error)
- func (s *SQLite) GetChatSessionByPlatform(ctx context.Context, platform, platformUserID, platformChannelID string) (*service.ChatSession, error)
- func (s *SQLite) GetChatSessionByTaskID(ctx context.Context, taskID string) (*service.ChatSession, error)
- func (s *SQLite) GetComment(ctx context.Context, id string) (*service.IssueComment, error)
- func (s *SQLite) GetConnection(ctx context.Context, id string) (*service.Connection, error)
- func (s *SQLite) GetConnectionByName(ctx context.Context, provider, name string) (*service.Connection, error)
- func (s *SQLite) GetCostByAgent(ctx context.Context, agentID string) (float64, error)
- func (s *SQLite) GetCostByBillingCode(ctx context.Context, billingCode string) (float64, error)
- func (s *SQLite) GetCostByGoal(ctx context.Context, goalID string) (float64, error)
- func (s *SQLite) GetCostByProject(ctx context.Context, projectID string) (float64, error)
- func (s *SQLite) GetGoal(ctx context.Context, id string) (*service.Goal, error)
- func (s *SQLite) GetGoalAncestry(ctx context.Context, id string) ([]service.Goal, error)
- func (s *SQLite) GetGuide(ctx context.Context, id string) (*service.Guide, error)
- func (s *SQLite) GetHeartbeat(ctx context.Context, agentID string) (*service.AgentHeartbeat, error)
- func (s *SQLite) GetHeartbeatRun(ctx context.Context, id string) (*service.HeartbeatRun, error)
- func (s *SQLite) GetLabel(ctx context.Context, id string) (*service.Label, error)
- func (s *SQLite) GetLatestRevision(ctx context.Context, agentID string) (*service.AgentConfigRevision, error)
- func (s *SQLite) GetMCPServer(ctx context.Context, id string) (*service.MCPServer, error)
- func (s *SQLite) GetMCPServerByName(ctx context.Context, name string) (*service.MCPServer, error)
- func (s *SQLite) GetMCPSet(ctx context.Context, id string) (*service.MCPSet, error)
- func (s *SQLite) GetMCPSetByName(ctx context.Context, name string) (*service.MCPSet, error)
- func (s *SQLite) GetMarketplaceSource(ctx context.Context, id string) (*service.MarketplaceSource, error)
- func (s *SQLite) GetNodeConfig(ctx context.Context, id string) (*service.NodeConfig, error)
- func (s *SQLite) GetOrganization(ctx context.Context, id string) (*service.Organization, error)
- func (s *SQLite) GetOrganizationAgent(ctx context.Context, id string) (*service.OrganizationAgent, error)
- func (s *SQLite) GetOrganizationAgentByPair(ctx context.Context, orgID, agentID string) (*service.OrganizationAgent, error)
- func (s *SQLite) GetPackSource(ctx context.Context, id string) (*service.PackSource, error)
- func (s *SQLite) GetProject(ctx context.Context, id string) (*service.Project, error)
- func (s *SQLite) GetProvider(ctx context.Context, key string) (*service.ProviderRecord, error)
- func (s *SQLite) GetRAGCollection(ctx context.Context, id string) (*service.RAGCollection, error)
- func (s *SQLite) GetRAGCollectionByName(ctx context.Context, name string) (*service.RAGCollection, error)
- func (s *SQLite) GetRAGPage(ctx context.Context, id string) (*service.RAGPage, error)
- func (s *SQLite) GetRAGPageBySource(ctx context.Context, collectionID, source string) (*service.RAGPage, error)
- func (s *SQLite) GetRAGState(ctx context.Context, key string) (*service.RAGState, error)
- func (s *SQLite) GetRevision(ctx context.Context, id string) (*service.AgentConfigRevision, error)
- func (s *SQLite) GetSkill(ctx context.Context, id string) (*service.Skill, error)
- func (s *SQLite) GetSkillByName(ctx context.Context, name string) (*service.Skill, error)
- func (s *SQLite) GetTask(ctx context.Context, id string) (*service.Task, error)
- func (s *SQLite) GetTokenTotalUsage(ctx context.Context, tokenID string) (int64, error)
- func (s *SQLite) GetTokenUsage(ctx context.Context, tokenID string) ([]service.TokenUsage, error)
- func (s *SQLite) GetTrigger(ctx context.Context, id string) (*service.Trigger, error)
- func (s *SQLite) GetTriggerByAlias(ctx context.Context, alias string) (*service.Trigger, error)
- func (s *SQLite) GetUsageGrouped(ctx context.Context, filter service.UsageFilter, groupBy string, limit int) ([]service.UsageSummary, error)
- func (s *SQLite) GetUsageSummary(ctx context.Context, filter service.UsageFilter) (service.UsageSummary, error)
- func (s *SQLite) GetUsageTimeSeries(ctx context.Context, filter service.UsageFilter, bucket string) ([]service.UsageTimeSeriesPoint, error)
- func (s *SQLite) GetUserPreference(ctx context.Context, userID, key string) (*service.UserPreference, error)
- func (s *SQLite) GetVariable(ctx context.Context, id string) (*service.Variable, error)
- func (s *SQLite) GetVariableByKey(ctx context.Context, key string) (*service.Variable, error)
- func (s *SQLite) GetWakeupRequest(ctx context.Context, id string) (*service.WakeupRequest, error)
- func (s *SQLite) GetWorkflow(ctx context.Context, id string) (*service.Workflow, error)
- func (s *SQLite) GetWorkflowByName(ctx context.Context, name string) (*service.Workflow, error)
- func (s *SQLite) GetWorkflowVersion(ctx context.Context, workflowID string, version int) (*service.WorkflowVersion, error)
- func (s *SQLite) IncrementIssueCounter(ctx context.Context, orgID string) (int64, error)
- func (s *SQLite) ListAPITokens(ctx context.Context, q *query.Query) (*service.ListResult[service.APIToken], error)
- func (s *SQLite) ListAgentBudgets(ctx context.Context) ([]service.AgentBudget, error)
- func (s *SQLite) ListAgentMemories(ctx context.Context, agentID, orgID string) ([]service.AgentMemory, error)
- func (s *SQLite) ListAgentOrganizations(ctx context.Context, agentID string) ([]service.OrganizationAgent, error)
- func (s *SQLite) ListAgentTaskSessions(ctx context.Context, agentID string) ([]service.AgentTaskSession, error)
- func (s *SQLite) ListAgents(ctx context.Context, q *query.Query) (*service.ListResult[service.Agent], error)
- func (s *SQLite) ListAllTriggers(ctx context.Context) ([]service.Trigger, error)
- func (s *SQLite) ListApprovals(ctx context.Context, q *query.Query) (*service.ListResult[service.Approval], error)
- func (s *SQLite) ListAuditEntries(ctx context.Context, q *query.Query) (*service.ListResult[service.AuditEntry], error)
- func (s *SQLite) ListBotConfigs(ctx context.Context, q *query.Query) (*service.ListResult[service.BotConfig], error)
- func (s *SQLite) ListChatMessages(ctx context.Context, sessionID string) ([]service.ChatMessage, error)
- func (s *SQLite) ListChatSessions(ctx context.Context, q *query.Query) (*service.ListResult[service.ChatSession], error)
- func (s *SQLite) ListChildTasks(ctx context.Context, parentID string) ([]service.Task, error)
- func (s *SQLite) ListCommentsByTask(ctx context.Context, taskID string) ([]service.IssueComment, error)
- func (s *SQLite) ListConnections(ctx context.Context, q *query.Query) (*service.ListResult[service.Connection], error)
- func (s *SQLite) ListConnectionsByProvider(ctx context.Context, provider string) ([]service.Connection, error)
- func (s *SQLite) ListCostEvents(ctx context.Context, q *query.Query) (*service.ListResult[service.CostEvent], error)
- func (s *SQLite) ListEnabledCronTriggers(ctx context.Context) ([]service.Trigger, error)
- func (s *SQLite) ListGoals(ctx context.Context, q *query.Query) (*service.ListResult[service.Goal], error)
- func (s *SQLite) ListGoalsByParent(ctx context.Context, parentID string) ([]service.Goal, error)
- func (s *SQLite) ListGuides(ctx context.Context, q *query.Query) (*service.ListResult[service.Guide], error)
- func (s *SQLite) ListHeartbeatRuns(ctx context.Context, agentID string, q *query.Query) (*service.ListResult[service.HeartbeatRun], error)
- func (s *SQLite) ListHeartbeats(ctx context.Context) ([]service.AgentHeartbeat, error)
- func (s *SQLite) ListLabels(ctx context.Context, orgID string) ([]service.Label, error)
- func (s *SQLite) ListLabelsForTask(ctx context.Context, taskID string) ([]service.Label, error)
- func (s *SQLite) ListMCPServers(ctx context.Context, q *query.Query) (*service.ListResult[service.MCPServer], error)
- func (s *SQLite) ListMCPSets(ctx context.Context, q *query.Query) (*service.ListResult[service.MCPSet], error)
- func (s *SQLite) ListMarketplaceSources(ctx context.Context) ([]service.MarketplaceSource, error)
- func (s *SQLite) ListModelPricing(ctx context.Context) ([]service.ModelPricing, error)
- func (s *SQLite) ListNodeConfigs(ctx context.Context, q *query.Query) (*service.ListResult[service.NodeConfig], error)
- func (s *SQLite) ListNodeConfigsByType(ctx context.Context, configType string) ([]service.NodeConfig, error)
- func (s *SQLite) ListOrgMemories(ctx context.Context, orgID string) ([]service.AgentMemory, error)
- func (s *SQLite) ListOrganizationAgents(ctx context.Context, orgID string) ([]service.OrganizationAgent, error)
- func (s *SQLite) ListOrganizations(ctx context.Context, q *query.Query) (*service.ListResult[service.Organization], error)
- func (s *SQLite) ListPackSources(ctx context.Context, q *query.Query) (*service.ListResult[service.PackSource], error)
- func (s *SQLite) ListPendingApprovals(ctx context.Context, orgID string) ([]service.Approval, error)
- func (s *SQLite) ListPendingForAgent(ctx context.Context, agentID string) ([]service.WakeupRequest, error)
- func (s *SQLite) ListProjects(ctx context.Context, q *query.Query) (*service.ListResult[service.Project], error)
- func (s *SQLite) ListProjectsByGoal(ctx context.Context, goalID string) ([]service.Project, error)
- func (s *SQLite) ListProjectsByOrganization(ctx context.Context, orgID string) ([]service.Project, error)
- func (s *SQLite) ListProviders(ctx context.Context, q *query.Query) (*service.ListResult[service.ProviderRecord], error)
- func (s *SQLite) ListRAGCollections(ctx context.Context, q *query.Query) (*service.ListResult[service.RAGCollection], error)
- func (s *SQLite) ListRAGPages(ctx context.Context, collectionID string, q *query.Query) (*service.ListResult[service.RAGPage], error)
- func (s *SQLite) ListRevisions(ctx context.Context, agentID string) ([]service.AgentConfigRevision, error)
- func (s *SQLite) ListSkills(ctx context.Context, q *query.Query) (*service.ListResult[service.Skill], error)
- func (s *SQLite) ListTasks(ctx context.Context, q *query.Query) (*service.ListResult[service.Task], error)
- func (s *SQLite) ListTasksByAgent(ctx context.Context, agentID string) ([]service.Task, error)
- func (s *SQLite) ListTasksByGoal(ctx context.Context, goalID string) ([]service.Task, error)
- func (s *SQLite) ListTasksForLabel(ctx context.Context, labelID string) ([]string, error)
- func (s *SQLite) ListTriggers(ctx context.Context, workflowID string) ([]service.Trigger, error)
- func (s *SQLite) ListUserPreferences(ctx context.Context, userID string) ([]service.UserPreference, error)
- func (s *SQLite) ListVariables(ctx context.Context, q *query.Query) (*service.ListResult[service.Variable], error)
- func (s *SQLite) ListWorkflowVersions(ctx context.Context, workflowID string) ([]service.WorkflowVersion, error)
- func (s *SQLite) ListWorkflows(ctx context.Context, q *query.Query) (*service.ListResult[service.Workflow], error)
- func (s *SQLite) MarkDispatched(ctx context.Context, id, runID string) error
- func (s *SQLite) MarkStale(ctx context.Context, threshold time.Duration) (int, error)
- func (s *SQLite) PromoteDeferred(ctx context.Context, agentID string) error
- func (s *SQLite) RecordAgentUsage(ctx context.Context, usage service.AgentUsageRecord) error
- func (s *SQLite) RecordAudit(ctx context.Context, entry service.AuditEntry) error
- func (s *SQLite) RecordCostEvent(ctx context.Context, event service.CostEvent) error
- func (s *SQLite) RecordHeartbeat(ctx context.Context, agentID string, metadata map[string]any) error
- func (s *SQLite) RecordUsage(ctx context.Context, tokenID, model string, usage service.Usage) error
- func (s *SQLite) ReleaseTask(ctx context.Context, taskID string) error
- func (s *SQLite) RemoveLabelFromTask(ctx context.Context, taskID, labelID string) error
- func (s *SQLite) ResetTokenUsage(ctx context.Context, tokenID string) error
- func (s *SQLite) RotateEncryptionKey(ctx context.Context, newKey []byte) error
- func (s *SQLite) SearchAgentMemories(ctx context.Context, agentID, orgID, query string) ([]service.AgentMemory, error)
- func (s *SQLite) SetActiveVersion(ctx context.Context, workflowID string, version int) error
- func (s *SQLite) SetAgentBudget(ctx context.Context, budget service.AgentBudget) error
- func (s *SQLite) SetEncryptionKey(newKey []byte)
- func (s *SQLite) SetModelPricing(ctx context.Context, pricing service.ModelPricing) error
- func (s *SQLite) SetRAGState(ctx context.Context, key string, value string) error
- func (s *SQLite) SetUserPreference(ctx context.Context, pref service.UserPreference) error
- func (s *SQLite) UpdateAPIToken(ctx context.Context, id string, token service.APIToken) (*service.APIToken, error)
- func (s *SQLite) UpdateAgent(ctx context.Context, id string, agent service.Agent) (*service.Agent, error)
- func (s *SQLite) UpdateApproval(ctx context.Context, id string, approval service.Approval) (*service.Approval, error)
- func (s *SQLite) UpdateBotConfig(ctx context.Context, id string, bot service.BotConfig) (*service.BotConfig, error)
- func (s *SQLite) UpdateChatSession(ctx context.Context, id string, session service.ChatSession) (*service.ChatSession, error)
- func (s *SQLite) UpdateComment(ctx context.Context, id string, comment service.IssueComment) (*service.IssueComment, error)
- func (s *SQLite) UpdateConnection(ctx context.Context, id string, c service.Connection) (*service.Connection, error)
- func (s *SQLite) UpdateGoal(ctx context.Context, id string, goal service.Goal) (*service.Goal, error)
- func (s *SQLite) UpdateGuide(ctx context.Context, id string, g service.Guide) (*service.Guide, error)
- func (s *SQLite) UpdateHeartbeatRun(ctx context.Context, id string, run service.HeartbeatRun) (*service.HeartbeatRun, error)
- func (s *SQLite) UpdateLabel(ctx context.Context, id string, label service.Label) (*service.Label, error)
- func (s *SQLite) UpdateLastUsed(ctx context.Context, id string) error
- func (s *SQLite) UpdateMCPServer(ctx context.Context, id string, srv service.MCPServer) (*service.MCPServer, error)
- func (s *SQLite) UpdateMCPSet(ctx context.Context, id string, set service.MCPSet) (*service.MCPSet, error)
- func (s *SQLite) UpdateMarketplaceSource(ctx context.Context, id string, src service.MarketplaceSource) (*service.MarketplaceSource, error)
- func (s *SQLite) UpdateNodeConfig(ctx context.Context, id string, nc service.NodeConfig) (*service.NodeConfig, error)
- func (s *SQLite) UpdateOrganization(ctx context.Context, id string, org service.Organization) (*service.Organization, error)
- func (s *SQLite) UpdateOrganizationAgent(ctx context.Context, id string, oa service.OrganizationAgent) (*service.OrganizationAgent, error)
- func (s *SQLite) UpdatePackSource(ctx context.Context, id string, ps service.PackSource) (*service.PackSource, error)
- func (s *SQLite) UpdateProject(ctx context.Context, id string, project service.Project) (*service.Project, error)
- func (s *SQLite) UpdateProvider(ctx context.Context, key string, record service.ProviderRecord) (*service.ProviderRecord, error)
- func (s *SQLite) UpdateRAGCollection(ctx context.Context, id string, c service.RAGCollection) (*service.RAGCollection, error)
- func (s *SQLite) UpdateSkill(ctx context.Context, id string, sk service.Skill) (*service.Skill, error)
- func (s *SQLite) UpdateTask(ctx context.Context, id string, task service.Task) (*service.Task, error)
- func (s *SQLite) UpdateTaskStatus(ctx context.Context, id string, status string, result string) error
- func (s *SQLite) UpdateTrigger(ctx context.Context, id string, t service.Trigger) (*service.Trigger, error)
- func (s *SQLite) UpdateVariable(ctx context.Context, id string, v service.Variable) (*service.Variable, error)
- func (s *SQLite) UpdateWorkflow(ctx context.Context, id string, w service.Workflow) (*service.Workflow, error)
- func (s *SQLite) UpsertAgentRuntimeState(ctx context.Context, state service.AgentRuntimeState) error
- func (s *SQLite) UpsertAgentTaskSession(ctx context.Context, session service.AgentTaskSession) error
- func (s *SQLite) UpsertRAGPage(ctx context.Context, page service.RAGPage) (*service.RAGPage, error)
Constants ¶
This section is empty.
Variables ¶
var DefaultTablePrefix = "at_"
Functions ¶
Types ¶
type SQLite ¶
type SQLite struct {
// contains filtered or unexported fields
}
func (*SQLite) AccumulateUsage ¶ added in v0.2.0
func (*SQLite) AddLabelToTask ¶ added in v0.2.0
func (*SQLite) CheckoutTask ¶ added in v0.2.0
func (*SQLite) CreateAPIToken ¶
func (*SQLite) CreateAgent ¶ added in v0.2.0
func (*SQLite) CreateAgentMemory ¶ added in v0.2.0
func (s *SQLite) CreateAgentMemory(ctx context.Context, mem service.AgentMemory) (*service.AgentMemory, error)
func (*SQLite) CreateAgentMemoryMessages ¶ added in v0.2.0
func (*SQLite) CreateApproval ¶ added in v0.2.0
func (*SQLite) CreateBotConfig ¶ added in v0.2.0
func (*SQLite) CreateChatMessage ¶ added in v0.2.0
func (s *SQLite) CreateChatMessage(ctx context.Context, msg service.ChatMessage) (*service.ChatMessage, error)
func (*SQLite) CreateChatMessages ¶ added in v0.2.0
func (*SQLite) CreateChatSession ¶ added in v0.2.0
func (s *SQLite) CreateChatSession(ctx context.Context, session service.ChatSession) (*service.ChatSession, error)
func (*SQLite) CreateComment ¶ added in v0.2.0
func (s *SQLite) CreateComment(ctx context.Context, comment service.IssueComment) (*service.IssueComment, error)
func (*SQLite) CreateConnection ¶ added in v0.2.1
func (s *SQLite) CreateConnection(ctx context.Context, c service.Connection) (*service.Connection, error)
func (*SQLite) CreateGoal ¶ added in v0.2.0
func (*SQLite) CreateGuide ¶ added in v0.2.1
func (*SQLite) CreateHeartbeatRun ¶ added in v0.2.0
func (s *SQLite) CreateHeartbeatRun(ctx context.Context, run service.HeartbeatRun) (*service.HeartbeatRun, error)
func (*SQLite) CreateLabel ¶ added in v0.2.0
func (*SQLite) CreateMCPServer ¶ added in v0.2.0
func (*SQLite) CreateMCPSet ¶ added in v0.2.0
func (*SQLite) CreateMarketplaceSource ¶ added in v0.2.0
func (s *SQLite) CreateMarketplaceSource(ctx context.Context, src service.MarketplaceSource) (*service.MarketplaceSource, error)
func (*SQLite) CreateNodeConfig ¶ added in v0.2.0
func (s *SQLite) CreateNodeConfig(ctx context.Context, nc service.NodeConfig) (*service.NodeConfig, error)
func (*SQLite) CreateOrCoalesce ¶ added in v0.2.0
func (s *SQLite) CreateOrCoalesce(ctx context.Context, req service.WakeupRequest) (*service.WakeupRequest, error)
func (*SQLite) CreateOrganization ¶ added in v0.2.0
func (s *SQLite) CreateOrganization(ctx context.Context, org service.Organization) (*service.Organization, error)
func (*SQLite) CreateOrganizationAgent ¶ added in v0.2.0
func (s *SQLite) CreateOrganizationAgent(ctx context.Context, oa service.OrganizationAgent) (*service.OrganizationAgent, error)
func (*SQLite) CreatePackSource ¶ added in v0.2.1
func (s *SQLite) CreatePackSource(ctx context.Context, ps service.PackSource) (*service.PackSource, error)
func (*SQLite) CreateProject ¶ added in v0.2.0
func (*SQLite) CreateProvider ¶
func (s *SQLite) CreateProvider(ctx context.Context, record service.ProviderRecord) (*service.ProviderRecord, error)
func (*SQLite) CreateRAGCollection ¶ added in v0.2.0
func (s *SQLite) CreateRAGCollection(ctx context.Context, c service.RAGCollection) (*service.RAGCollection, error)
func (*SQLite) CreateRevision ¶ added in v0.2.0
func (s *SQLite) CreateRevision(ctx context.Context, rev service.AgentConfigRevision) (*service.AgentConfigRevision, error)
func (*SQLite) CreateSkill ¶ added in v0.2.0
func (*SQLite) CreateTask ¶ added in v0.2.0
func (*SQLite) CreateTrigger ¶ added in v0.2.0
func (*SQLite) CreateVariable ¶ added in v0.2.0
func (*SQLite) CreateWorkflow ¶ added in v0.2.0
func (*SQLite) CreateWorkflowVersion ¶ added in v0.2.0
func (s *SQLite) CreateWorkflowVersion(ctx context.Context, v service.WorkflowVersion) (*service.WorkflowVersion, error)
func (*SQLite) DeleteAPIToken ¶
func (*SQLite) DeleteAgent ¶ added in v0.2.0
func (*SQLite) DeleteAgentMemory ¶ added in v0.2.0
func (*SQLite) DeleteAgentTaskSession ¶ added in v0.2.0
func (*SQLite) DeleteBotConfig ¶ added in v0.2.0
func (*SQLite) DeleteChatMessages ¶ added in v0.2.0
func (*SQLite) DeleteChatSession ¶ added in v0.2.0
func (*SQLite) DeleteComment ¶ added in v0.2.0
func (*SQLite) DeleteConnection ¶ added in v0.2.1
func (*SQLite) DeleteGoal ¶ added in v0.2.0
func (*SQLite) DeleteGuide ¶ added in v0.2.1
func (*SQLite) DeleteLabel ¶ added in v0.2.0
func (*SQLite) DeleteMCPServer ¶ added in v0.2.0
func (*SQLite) DeleteMCPSet ¶ added in v0.2.0
func (*SQLite) DeleteMarketplaceSource ¶ added in v0.2.0
func (*SQLite) DeleteNodeConfig ¶ added in v0.2.0
func (*SQLite) DeleteOrganization ¶ added in v0.2.0
func (*SQLite) DeleteOrganizationAgent ¶ added in v0.2.0
func (*SQLite) DeleteOrganizationAgentByPair ¶ added in v0.2.0
func (*SQLite) DeletePackSource ¶ added in v0.2.1
func (*SQLite) DeleteProject ¶ added in v0.2.0
func (*SQLite) DeleteProvider ¶
func (*SQLite) DeleteRAGCollection ¶ added in v0.2.0
func (*SQLite) DeleteRAGPage ¶ added in v0.2.0
func (*SQLite) DeleteRAGPageBySource ¶ added in v0.2.0
func (*SQLite) DeleteRAGPagesByCollectionID ¶ added in v0.2.0
func (*SQLite) DeleteSkill ¶ added in v0.2.0
func (*SQLite) DeleteTask ¶ added in v0.2.0
func (*SQLite) DeleteTrigger ¶ added in v0.2.0
func (*SQLite) DeleteUserPreference ¶ added in v0.2.0
func (*SQLite) DeleteVariable ¶ added in v0.2.0
func (*SQLite) DeleteWorkflow ¶ added in v0.2.0
func (*SQLite) GetAPITokenByHash ¶
func (*SQLite) GetActiveRun ¶ added in v0.2.0
func (*SQLite) GetAgentBudget ¶ added in v0.2.0
func (*SQLite) GetAgentMemory ¶ added in v0.2.0
func (*SQLite) GetAgentMemoryMessages ¶ added in v0.2.0
func (*SQLite) GetAgentRuntimeState ¶ added in v0.2.0
func (*SQLite) GetAgentTaskSession ¶ added in v0.2.0
func (*SQLite) GetAgentTotalSpend ¶ added in v0.2.0
func (*SQLite) GetAgentUsage ¶ added in v0.2.0
func (*SQLite) GetApproval ¶ added in v0.2.0
func (*SQLite) GetAuditTrail ¶ added in v0.2.0
func (*SQLite) GetBotConfig ¶ added in v0.2.0
func (*SQLite) GetChatSession ¶ added in v0.2.0
func (*SQLite) GetChatSessionByPlatform ¶ added in v0.2.0
func (*SQLite) GetChatSessionByTaskID ¶ added in v0.2.0
func (*SQLite) GetComment ¶ added in v0.2.0
func (*SQLite) GetConnection ¶ added in v0.2.1
func (*SQLite) GetConnectionByName ¶ added in v0.2.1
func (*SQLite) GetCostByAgent ¶ added in v0.2.0
func (*SQLite) GetCostByBillingCode ¶ added in v0.2.0
func (*SQLite) GetCostByGoal ¶ added in v0.2.0
func (*SQLite) GetCostByProject ¶ added in v0.2.0
func (*SQLite) GetGoalAncestry ¶ added in v0.2.0
func (*SQLite) GetHeartbeat ¶ added in v0.2.0
func (*SQLite) GetHeartbeatRun ¶ added in v0.2.0
func (*SQLite) GetLatestRevision ¶ added in v0.2.0
func (*SQLite) GetMCPServer ¶ added in v0.2.0
func (*SQLite) GetMCPServerByName ¶ added in v0.2.0
func (*SQLite) GetMCPSetByName ¶ added in v0.2.0
func (*SQLite) GetMarketplaceSource ¶ added in v0.2.0
func (*SQLite) GetNodeConfig ¶ added in v0.2.0
func (*SQLite) GetOrganization ¶ added in v0.2.0
func (*SQLite) GetOrganizationAgent ¶ added in v0.2.0
func (*SQLite) GetOrganizationAgentByPair ¶ added in v0.2.0
func (*SQLite) GetPackSource ¶ added in v0.2.1
func (*SQLite) GetProject ¶ added in v0.2.0
func (*SQLite) GetProvider ¶
func (*SQLite) GetRAGCollection ¶ added in v0.2.0
func (*SQLite) GetRAGCollectionByName ¶ added in v0.2.0
func (*SQLite) GetRAGPage ¶ added in v0.2.0
func (*SQLite) GetRAGPageBySource ¶ added in v0.2.0
func (*SQLite) GetRAGState ¶ added in v0.2.0
func (*SQLite) GetRevision ¶ added in v0.2.0
func (*SQLite) GetSkillByName ¶ added in v0.2.0
func (*SQLite) GetTokenTotalUsage ¶ added in v0.2.0
func (*SQLite) GetTokenUsage ¶ added in v0.2.0
func (*SQLite) GetTrigger ¶ added in v0.2.0
func (*SQLite) GetTriggerByAlias ¶ added in v0.2.0
func (*SQLite) GetUsageGrouped ¶ added in v0.2.1
func (s *SQLite) GetUsageGrouped(ctx context.Context, filter service.UsageFilter, groupBy string, limit int) ([]service.UsageSummary, error)
func (*SQLite) GetUsageSummary ¶ added in v0.2.1
func (s *SQLite) GetUsageSummary(ctx context.Context, filter service.UsageFilter) (service.UsageSummary, error)
func (*SQLite) GetUsageTimeSeries ¶ added in v0.2.1
func (s *SQLite) GetUsageTimeSeries(ctx context.Context, filter service.UsageFilter, bucket string) ([]service.UsageTimeSeriesPoint, error)
func (*SQLite) GetUserPreference ¶ added in v0.2.0
func (*SQLite) GetVariable ¶ added in v0.2.0
func (*SQLite) GetVariableByKey ¶ added in v0.2.0
func (*SQLite) GetWakeupRequest ¶ added in v0.2.0
func (*SQLite) GetWorkflow ¶ added in v0.2.0
func (*SQLite) GetWorkflowByName ¶ added in v0.2.1
func (*SQLite) GetWorkflowVersion ¶ added in v0.2.0
func (*SQLite) IncrementIssueCounter ¶ added in v0.2.0
func (*SQLite) ListAPITokens ¶
func (*SQLite) ListAgentBudgets ¶ added in v0.2.1
ListAgentBudgets returns every configured agent budget.
func (*SQLite) ListAgentMemories ¶ added in v0.2.0
func (*SQLite) ListAgentOrganizations ¶ added in v0.2.0
func (*SQLite) ListAgentTaskSessions ¶ added in v0.2.0
func (*SQLite) ListAgents ¶ added in v0.2.0
func (*SQLite) ListAllTriggers ¶ added in v0.2.0
func (*SQLite) ListApprovals ¶ added in v0.2.0
func (*SQLite) ListAuditEntries ¶ added in v0.2.0
func (s *SQLite) ListAuditEntries(ctx context.Context, q *query.Query) (*service.ListResult[service.AuditEntry], error)
func (*SQLite) ListBotConfigs ¶ added in v0.2.0
func (*SQLite) ListChatMessages ¶ added in v0.2.0
func (*SQLite) ListChatSessions ¶ added in v0.2.0
func (s *SQLite) ListChatSessions(ctx context.Context, q *query.Query) (*service.ListResult[service.ChatSession], error)
func (*SQLite) ListChildTasks ¶ added in v0.2.0
func (*SQLite) ListCommentsByTask ¶ added in v0.2.0
func (*SQLite) ListConnections ¶ added in v0.2.1
func (s *SQLite) ListConnections(ctx context.Context, q *query.Query) (*service.ListResult[service.Connection], error)
func (*SQLite) ListConnectionsByProvider ¶ added in v0.2.1
func (*SQLite) ListCostEvents ¶ added in v0.2.0
func (*SQLite) ListEnabledCronTriggers ¶ added in v0.2.0
func (*SQLite) ListGoalsByParent ¶ added in v0.2.0
func (*SQLite) ListGuides ¶ added in v0.2.1
func (*SQLite) ListHeartbeatRuns ¶ added in v0.2.0
func (*SQLite) ListHeartbeats ¶ added in v0.2.0
func (*SQLite) ListLabels ¶ added in v0.2.0
func (*SQLite) ListLabelsForTask ¶ added in v0.2.0
func (*SQLite) ListMCPServers ¶ added in v0.2.0
func (*SQLite) ListMCPSets ¶ added in v0.2.0
func (*SQLite) ListMarketplaceSources ¶ added in v0.2.0
func (*SQLite) ListModelPricing ¶ added in v0.2.0
func (*SQLite) ListNodeConfigs ¶ added in v0.2.0
func (s *SQLite) ListNodeConfigs(ctx context.Context, q *query.Query) (*service.ListResult[service.NodeConfig], error)
func (*SQLite) ListNodeConfigsByType ¶ added in v0.2.0
func (*SQLite) ListOrgMemories ¶ added in v0.2.0
func (*SQLite) ListOrganizationAgents ¶ added in v0.2.0
func (*SQLite) ListOrganizations ¶ added in v0.2.0
func (s *SQLite) ListOrganizations(ctx context.Context, q *query.Query) (*service.ListResult[service.Organization], error)
func (*SQLite) ListPackSources ¶ added in v0.2.1
func (s *SQLite) ListPackSources(ctx context.Context, q *query.Query) (*service.ListResult[service.PackSource], error)
func (*SQLite) ListPendingApprovals ¶ added in v0.2.0
func (*SQLite) ListPendingForAgent ¶ added in v0.2.0
func (*SQLite) ListProjects ¶ added in v0.2.0
func (*SQLite) ListProjectsByGoal ¶ added in v0.2.0
func (*SQLite) ListProjectsByOrganization ¶ added in v0.2.0
func (*SQLite) ListProviders ¶
func (s *SQLite) ListProviders(ctx context.Context, q *query.Query) (*service.ListResult[service.ProviderRecord], error)
func (*SQLite) ListRAGCollections ¶ added in v0.2.0
func (s *SQLite) ListRAGCollections(ctx context.Context, q *query.Query) (*service.ListResult[service.RAGCollection], error)
func (*SQLite) ListRAGPages ¶ added in v0.2.0
func (*SQLite) ListRevisions ¶ added in v0.2.0
func (*SQLite) ListSkills ¶ added in v0.2.0
func (*SQLite) ListTasksByAgent ¶ added in v0.2.0
func (*SQLite) ListTasksByGoal ¶ added in v0.2.0
func (*SQLite) ListTasksForLabel ¶ added in v0.2.0
func (*SQLite) ListTriggers ¶ added in v0.2.0
func (*SQLite) ListUserPreferences ¶ added in v0.2.0
func (*SQLite) ListVariables ¶ added in v0.2.0
func (*SQLite) ListWorkflowVersions ¶ added in v0.2.0
func (*SQLite) ListWorkflows ¶ added in v0.2.0
func (*SQLite) MarkDispatched ¶ added in v0.2.0
func (*SQLite) PromoteDeferred ¶ added in v0.2.0
func (*SQLite) RecordAgentUsage ¶ added in v0.2.0
func (*SQLite) RecordAudit ¶ added in v0.2.0
func (*SQLite) RecordCostEvent ¶ added in v0.2.0
func (*SQLite) RecordHeartbeat ¶ added in v0.2.0
func (*SQLite) RecordUsage ¶ added in v0.2.0
func (*SQLite) ReleaseTask ¶ added in v0.2.0
func (*SQLite) RemoveLabelFromTask ¶ added in v0.2.0
func (*SQLite) ResetTokenUsage ¶ added in v0.2.0
func (*SQLite) RotateEncryptionKey ¶ added in v0.1.3
RotateEncryptionKey decrypts all provider configs with the current key, re-encrypts them with newKey, and updates the rows atomically. Passing nil as newKey disables encryption (stores plaintext).
func (*SQLite) SearchAgentMemories ¶ added in v0.2.0
func (*SQLite) SetActiveVersion ¶ added in v0.2.0
func (*SQLite) SetAgentBudget ¶ added in v0.2.0
func (*SQLite) SetEncryptionKey ¶ added in v0.1.3
SetEncryptionKey updates the in-memory encryption key without re-encrypting database rows. Used by peer instances when they receive a key rotation broadcast from the instance that performed the actual rotation.
func (*SQLite) SetModelPricing ¶ added in v0.2.0
func (*SQLite) SetRAGState ¶ added in v0.2.0
func (*SQLite) SetUserPreference ¶ added in v0.2.0
func (*SQLite) UpdateAPIToken ¶
func (*SQLite) UpdateAgent ¶ added in v0.2.0
func (*SQLite) UpdateApproval ¶ added in v0.2.0
func (*SQLite) UpdateBotConfig ¶ added in v0.2.0
func (*SQLite) UpdateChatSession ¶ added in v0.2.0
func (s *SQLite) UpdateChatSession(ctx context.Context, id string, session service.ChatSession) (*service.ChatSession, error)
func (*SQLite) UpdateComment ¶ added in v0.2.0
func (s *SQLite) UpdateComment(ctx context.Context, id string, comment service.IssueComment) (*service.IssueComment, error)
func (*SQLite) UpdateConnection ¶ added in v0.2.1
func (s *SQLite) UpdateConnection(ctx context.Context, id string, c service.Connection) (*service.Connection, error)
func (*SQLite) UpdateGoal ¶ added in v0.2.0
func (*SQLite) UpdateGuide ¶ added in v0.2.1
func (*SQLite) UpdateHeartbeatRun ¶ added in v0.2.0
func (s *SQLite) UpdateHeartbeatRun(ctx context.Context, id string, run service.HeartbeatRun) (*service.HeartbeatRun, error)
func (*SQLite) UpdateLabel ¶ added in v0.2.0
func (*SQLite) UpdateLastUsed ¶
func (*SQLite) UpdateMCPServer ¶ added in v0.2.0
func (*SQLite) UpdateMCPSet ¶ added in v0.2.0
func (*SQLite) UpdateMarketplaceSource ¶ added in v0.2.0
func (s *SQLite) UpdateMarketplaceSource(ctx context.Context, id string, src service.MarketplaceSource) (*service.MarketplaceSource, error)
func (*SQLite) UpdateNodeConfig ¶ added in v0.2.0
func (s *SQLite) UpdateNodeConfig(ctx context.Context, id string, nc service.NodeConfig) (*service.NodeConfig, error)
func (*SQLite) UpdateOrganization ¶ added in v0.2.0
func (s *SQLite) UpdateOrganization(ctx context.Context, id string, org service.Organization) (*service.Organization, error)
func (*SQLite) UpdateOrganizationAgent ¶ added in v0.2.0
func (s *SQLite) UpdateOrganizationAgent(ctx context.Context, id string, oa service.OrganizationAgent) (*service.OrganizationAgent, error)
func (*SQLite) UpdatePackSource ¶ added in v0.2.1
func (s *SQLite) UpdatePackSource(ctx context.Context, id string, ps service.PackSource) (*service.PackSource, error)
func (*SQLite) UpdateProject ¶ added in v0.2.0
func (*SQLite) UpdateProvider ¶
func (s *SQLite) UpdateProvider(ctx context.Context, key string, record service.ProviderRecord) (*service.ProviderRecord, error)
func (*SQLite) UpdateRAGCollection ¶ added in v0.2.0
func (s *SQLite) UpdateRAGCollection(ctx context.Context, id string, c service.RAGCollection) (*service.RAGCollection, error)
func (*SQLite) UpdateSkill ¶ added in v0.2.0
func (*SQLite) UpdateTask ¶ added in v0.2.0
func (*SQLite) UpdateTaskStatus ¶ added in v0.2.0
func (*SQLite) UpdateTrigger ¶ added in v0.2.0
func (*SQLite) UpdateVariable ¶ added in v0.2.0
func (*SQLite) UpdateWorkflow ¶ added in v0.2.0
func (*SQLite) UpsertAgentRuntimeState ¶ added in v0.2.0
func (*SQLite) UpsertAgentTaskSession ¶ added in v0.2.0
Source Files
¶
- agent-budgets.go
- agent-config-revisions.go
- agent-memory.go
- agent-runtime-state.go
- agent-task-sessions.go
- agents.go
- approvals.go
- audit.go
- bot-configs.go
- chat-sessions.go
- connections.go
- cost-events.go
- goals.go
- guides.go
- heartbeat-runs.go
- heartbeats.go
- issue-comments.go
- labels.go
- marketplace-sources.go
- mcp-servers.go
- mcp-sets.go
- migrate.go
- node-configs.go
- organization-agents.go
- organizations.go
- pack-sources.go
- projects.go
- rag-collections.go
- rag-pages.go
- rag_states.go
- secrets.go
- skills.go
- sqlite3.go
- tasks.go
- token-usage.go
- tokens.go
- triggers.go
- usage.go
- user-preferences.go
- utils.go
- wakeup-requests.go
- workflow_versions.go
- workflows.go
Click to show internal directories.
Click to hide internal directories.